
// Declare gtag to inform TypeScript about its existence
declare var gtag: any;

// Helper function to display messages to the user
function displayMessage(formElementId: string, message: string, isSuccess: boolean) {
    const form = document.getElementById(formElementId);
    if (!form) return;

    let messageContainer = form.querySelector('.form-message-container');
    if (!messageContainer) {
        messageContainer = document.createElement('div');
        messageContainer.className = 'form-message-container mt-4 text-center text-sm';
        messageContainer.setAttribute('aria-live', 'polite');
        // Insert after the last form element or before any existing non-input element like a paragraph
        const formElements = (form as HTMLFormElement).elements;
        if (formElements && formElements.length > 0) {
            const lastFormElement = formElements[formElements.length -1];
            if(lastFormElement && lastFormElement.nextSibling) {
                lastFormElement.parentNode?.insertBefore(messageContainer, lastFormElement.nextSibling);
            } else {
                form.appendChild(messageContainer);
            }
        } else {
             form.appendChild(messageContainer);
        }
    }
    
    messageContainer.textContent = message;
    messageContainer.className = `form-message-container mt-4 text-center text-sm ${isSuccess ? 'text-brand-secondary' : 'text-red-400'}`;
}


// --- Form Handlers with Google Ads Conversion Tracking ---

// 1. Login/Signup Form (index.html #login-section)
const loginForm = document.getElementById('login-form') as HTMLFormElement | null;
if (loginForm) {
    loginForm.addEventListener('submit', function(event) {
        event.preventDefault();
        const currentForm = event.currentTarget as HTMLFormElement;
        const emailInput = currentForm.elements.namedItem('email') as HTMLInputElement | null;
        const passwordInput = currentForm.elements.namedItem('password') as HTMLInputElement | null;
        const email = emailInput?.value;
        const password = passwordInput?.value;
        const formMessageContainer = currentForm.querySelector('#form-message') || document.getElementById('form-message');


        if (!email || !password) {
            if (formMessageContainer) formMessageContainer.textContent = 'لطفاً تمامی فیلدها را پر کنید.';
            if (formMessageContainer) formMessageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }
        if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
             if (formMessageContainer) formMessageContainer.textContent = 'فرمت ایمیل نامعتبر است.';
             if (formMessageContainer) formMessageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }

        // Simulate successful submission (replace with actual backend call)
        console.log('Login/Signup attempt:', { email });
        if (formMessageContainer) formMessageContainer.textContent = 'در حال ارسال اطلاعات...';
        if (formMessageContainer) formMessageContainer.className = 'mt-4 text-center text-sm text-gray-400';


        setTimeout(() => {
            // Assuming submission is successful
            if (formMessageContainer) formMessageContainer.textContent = 'عملیات با موفقیت انجام شد!';
            if (formMessageContainer) formMessageContainer.className = 'mt-4 text-center text-sm text-brand-secondary';
            
            // Trigger Google Ads Conversion for Signup/Login
            // Replace 'AW-YOUR_CONVERSION_ID/YOUR_SIGNUP_LABEL' with your actual conversion ID and label for signups
            // Replace 'AW-YOUR_CONVERSION_ID/YOUR_LOGIN_LABEL' for logins if tracked separately
            if (typeof gtag === 'function') {
                // Determine if it's a signup or login to send the correct label
                // For this example, we'll use a generic one. You might have separate forms or logic.
                gtag('event', 'conversion', {'send_to': 'AW-YOUR_CONVERSION_ID/SIGNUP_LOGIN_CONVERSION_LABEL'});
                console.log('gtag conversion for signup/login sent.');
            } else {
                console.warn('gtag function not found. Google Ads conversion not sent.');
            }
            loginForm.reset();
        }, 1500);
    });
}


// 2. Newsletter Subscription Form (index.html #newsletter-section)
const newsletterFormIndex = document.getElementById('newsletter-form-index') as HTMLFormElement | null;
if (newsletterFormIndex) {
    newsletterFormIndex.addEventListener('submit', function(event) {
        event.preventDefault();
        const currentForm = event.currentTarget as HTMLFormElement;
        const emailInput = currentForm.elements.namedItem('email') as HTMLInputElement | null;
        const email = emailInput?.value;
        const messageContainer = currentForm.querySelector('#newsletter-message-index') || document.getElementById('newsletter-message-index');

        if (!email || !/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            if(messageContainer) messageContainer.textContent = 'لطفاً ایمیل معتبری وارد کنید.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }
        
        if(messageContainer) messageContainer.textContent = 'در حال ارسال...';
        if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-gray-400';

        // Simulate successful submission
        setTimeout(() => {
            if(messageContainer) messageContainer.textContent = 'از عضویت شما سپاسگزاریم!';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-brand-secondary';
            
            // Trigger Google Ads Conversion for Newsletter Subscription
            // Replace 'AW-YOUR_CONVERSION_ID/YOUR_NEWSLETTER_LABEL' with your actual conversion ID and label
            if (typeof gtag === 'function') {
                gtag('event', 'conversion', {'send_to': 'AW-YOUR_CONVERSION_ID/NEWSLETTER_CONVERSION_LABEL'});
                console.log('gtag conversion for newsletter (index) sent.');
            } else {
                console.warn('gtag function not found. Google Ads conversion not sent.');
            }
            newsletterFormIndex.reset();
        }, 1000);
    });
}

// 3. Newsletter Subscription Form (newsletter.html)
const newsletterFormPage = document.getElementById('newsletter-form-page') as HTMLFormElement | null; // Assuming this ID for newsletter.html form
if (newsletterFormPage) {
    newsletterFormPage.addEventListener('submit', function(event) {
        event.preventDefault();
        const currentForm = event.currentTarget as HTMLFormElement;
        const emailInput = currentForm.elements.namedItem('email') as HTMLInputElement | null;
        const email = emailInput?.value;
        const messageContainer = currentForm.querySelector('#newsletter-message-page') || document.getElementById('newsletter-message-page');


        if (!email || !/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            if(messageContainer) messageContainer.textContent = 'لطفاً ایمیل معتبری وارد کنید.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }

        if(messageContainer) messageContainer.textContent = 'در حال ارسال...';
        if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-gray-400';
        
        setTimeout(() => {
             if(messageContainer) messageContainer.textContent = 'از عضویت شما سپاسگزاریم!';
             if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-brand-secondary';

            if (typeof gtag === 'function') {
                gtag('event', 'conversion', {'send_to': 'AW-YOUR_CONVERSION_ID/NEWSLETTER_CONVERSION_LABEL'}); // Same label as index one likely
                console.log('gtag conversion for newsletter (page) sent.');
            } else {
                 console.warn('gtag function not found. Google Ads conversion not sent.');
            }
            newsletterFormPage.reset();
        }, 1000);
    });
}

// 4. Contact Form (contact.html)
const contactForm = document.getElementById('contact-us-form') as HTMLFormElement | null; // Assuming this ID for contact.html form
if (contactForm) {
    contactForm.addEventListener('submit', function(event) {
        event.preventDefault();
        const currentForm = event.currentTarget as HTMLFormElement;
        // Basic validation
        const nameInput = currentForm.elements.namedItem('contact-name') as HTMLInputElement | null;
        const emailInput = currentForm.elements.namedItem('email') as HTMLInputElement | null;
        const subjectInput = currentForm.elements.namedItem('contact-subject') as HTMLInputElement | null;
        const messageInput = currentForm.elements.namedItem('message') as HTMLTextAreaElement | null;

        const name = nameInput?.value;
        const email = emailInput?.value;
        const subject = subjectInput?.value;
        const message = messageInput?.value;
        const messageContainer = currentForm.querySelector('#contact-form-message') || document.getElementById('contact-form-message');


        if (!name || !email || !subject || !message) {
            if(messageContainer) messageContainer.textContent = 'لطفاً تمامی فیلدها را تکمیل کنید.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }
        if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            if(messageContainer) messageContainer.textContent = 'فرمت ایمیل نامعتبر است.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }

        if(messageContainer) messageContainer.textContent = 'در حال ارسال پیام شما...';
        if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-gray-400';

        setTimeout(() => {
            if(messageContainer) messageContainer.textContent = 'پیام شما با موفقیت ارسال شد. سپاسگزاریم!';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-brand-secondary';
            
            // Trigger Google Ads Conversion for Contact Form Submission
            // Replace 'AW-YOUR_CONVERSION_ID/YOUR_CONTACT_LABEL'
            if (typeof gtag === 'function') {
                gtag('event', 'conversion', {'send_to': 'AW-YOUR_CONVERSION_ID/CONTACT_FORM_CONVERSION_LABEL'});
                console.log('gtag conversion for contact form sent.');
            } else {
                 console.warn('gtag function not found. Google Ads conversion not sent.');
            }
            contactForm.reset();
        }, 1000);
    });
}

// 5. Report Issue Form (report-issue.html)
const reportIssueForm = document.getElementById('report-issue-form') as HTMLFormElement | null; // Assuming this ID
if (reportIssueForm) {
    reportIssueForm.addEventListener('submit', function(event) {
        event.preventDefault();
        const currentForm = event.currentTarget as HTMLFormElement;
        const issueTypeInput = currentForm.elements.namedItem('issue-type') as HTMLSelectElement | HTMLInputElement | null; // Could be select or input
        const descriptionInput = currentForm.elements.namedItem('description') as HTMLTextAreaElement | null;
        
        const issueType = issueTypeInput?.value;
        const description = descriptionInput?.value;
        const messageContainer = currentForm.querySelector('#report-form-message') || document.getElementById('report-form-message');


        if (!issueType || !description) {
            if(messageContainer) messageContainer.textContent = 'لطفاً نوع مشکل و توضیحات را ارائه دهید.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-red-400';
            return;
        }

        if(messageContainer) messageContainer.textContent = 'در حال ارسال گزارش...';
        if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-gray-400';

        setTimeout(() => {
            if(messageContainer) messageContainer.textContent = 'گزارش شما با موفقیت ثبت شد. از همکاری شما متشکریم.';
            if(messageContainer) messageContainer.className = 'mt-4 text-center text-sm text-brand-secondary';

            // Trigger Google Ads Conversion for Issue Report
            // Replace 'AW-YOUR_CONVERSION_ID/YOUR_REPORT_ISSUE_LABEL'
            if (typeof gtag === 'function') {
                gtag('event', 'conversion', {'send_to': 'AW-YOUR_CONVERSION_ID/REPORT_ISSUE_CONVERSION_LABEL'});
                console.log('gtag conversion for report issue sent.');
            } else {
                console.warn('gtag function not found. Google Ads conversion not sent.');
            }
            reportIssueForm.reset();
        }, 1000);
    });
}


document.addEventListener('DOMContentLoaded', () => {
    // Any other global JS initializations can go here.
    console.log('Kipool.pro scripts initialized.');
});
